@@ -268,7 +268,7 @@ def assign_values(X: np.array, var_list: list) -> dict:
     return result
 
 
-def modify_hyper_parameter_levels(fun_control, hyperparameter, levels) -> dict:
+def modify_hyper_parameter_levels(fun_control, hyperparameter, levels) -> None:
     """
     This function modifies the levels of a hyperparameter in the fun_control dictionary.
 
@@ -281,8 +281,7 @@ def modify_hyper_parameter_levels(fun_control, hyperparameter, levels) -> dict:
             list of levels
 
     Returns:
-        fun_control (dict):
-            updated fun_control
+        None.
 
     Examples:
         >>> fun_control = {}
@@ -298,7 +297,7 @@ def modify_hyper_parameter_levels(fun_control, hyperparameter, levels) -> dict:
     fun_control["core_model_hyper_dict"][hyperparameter].update({"upper": len(levels) - 1})
 
 
-def modify_hyper_parameter_bounds(fun_control, hyperparameter, bounds) -> dict:
+def modify_hyper_parameter_bounds(fun_control, hyperparameter, bounds) -> None:
     """
     Args:
         fun_control (dict):
@@ -310,8 +309,7 @@ def modify_hyper_parameter_bounds(fun_control, hyperparameter, bounds) -> dict:
             and the second value represents the upper bound.
 
     Returns:
-        fun_control (dict):
-            updated fun_control
+        None.
 
     Examples:
         >>> from spotPython.hyperparameters.values import modify_hyper_parameter_levels
@@ -386,7 +384,9 @@ def get_default_values(fun_control) -> dict:
 
 
 def get_var_type(fun_control) -> list:
-    """Get the types of the values from the dictionary fun_control as a list.
+    """
+    Get the types of the values from the dictionary fun_control as a list.
+    If no "core_model_hyper_dict" key exists in fun_control, return None.
 
     Args:
         fun_control (dict):
@@ -427,9 +427,12 @@ def get_var_type(fun_control) -> list:
             get_var_type(d)
             ['factor', 'factor', 'factor', 'factor', 'factor']
     """
-    return list(
-        fun_control["core_model_hyper_dict"][key]["type"] for key in fun_control["core_model_hyper_dict"].keys()
-    )
+    if "core_model_hyper_dict" not in fun_control.keys():
+        return None
+    else:
+        return list(
+            fun_control["core_model_hyper_dict"][key]["type"] for key in fun_control["core_model_hyper_dict"].keys()
+        )
 
 
 def get_transform(fun_control) -> list:
@@ -486,6 +489,7 @@ def get_transform(fun_control) -> list:
 
 def get_var_name(fun_control) -> list:
     """Get the names of the values from the dictionary fun_control as a list.
+    If no "core_model_hyper_dict" key exists in fun_control, return None.
 
     Args:
         fun_control (dict):
@@ -532,7 +536,10 @@ def get_var_name(fun_control) -> list:
                 'binary_split',
                 'stop_mem_management']
     """
-    return list(fun_control["core_model_hyper_dict"].keys())
+    if "core_model_hyper_dict" not in fun_control.keys():
+        return None
+    else:
+        return list(fun_control["core_model_hyper_dict"].keys())
 
 
 def get_bound_values(fun_control: dict, bound: str, as_list: bool = False) -> Union[List, np.ndarray]:
@@ -1015,217 +1022,66 @@ def create_model(config, fun_control, **kwargs) -> object:
     return fun_control["core_model"](**config, **kwargs)
 
 
-def set_fun_control_fun_evals(fun_control, fun_evals) -> dict:
+def set_fun_control_key_value(fun_control, key, value, replace=False) -> None:
     """
-    This function sets the number of function evaluations in the fun_control dictionary.
+    This function sets the key value pair in the fun_control dictionary.
 
     Args:
         fun_control (dict):
             fun_control dictionary
-        fun_evals (int): number of function evaluations
+        key (str): key
+        value (Any): value
+        replace (bool): replace value if key already exists. Default is False.
 
     Returns:
-        fun_control (dict):
-            updated fun_control
+        None.
 
     Attributes:
-        fun_evals (int): number of function evaluations
+        key (str): key
+        value (Any): value
 
     Examples:
         >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import set_fun_control_fun_evals
+            from spotPython.hyperparameters.values import set_fun_control_key_value
             fun_control = fun_control_init()
-            set_fun_control_fun_evals(fun_control=fun_control,
-                          fun_evals=5)
-            fun_control["fun_evals"]
+            set_fun_control_key_value(fun_control=fun_control,
+                          key="key",
+                          value="value")
+            fun_control["key"]
 
     """
-    fun_control.update({"fun_evals": fun_evals})
+    if replace:
+        fun_control.update({key: value})
+    else:
+        if key not in fun_control.keys():
+            fun_control.update({key: value})
 
 
-def get_fun_control_fun_evals(fun_control=None) -> int:
+def get_fun_control_key_value(fun_control=None, key=None) -> Any:
     """
-    This function gets the number of function evaluations from the fun_control dictionary.
+    This function gets the key value pair from the fun_control dictionary.
+    If the key does not exist, return None.
+    If the fun_control dictionary is None, return None.
 
     Args:
         fun_control (dict):
             fun_control dictionary
+        key (str): key
 
     Returns:
-        fun_evals (int):
-            number of function evaluations
+        value (Any):
+            value
 
     Examples:
         >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import get_fun_control_fun_evals
+            from spotPython.hyperparameters.values import get_fun_control_key_value
             fun_control = fun_control_init()
-            get_fun_control_fun_evals(fun_control=fun_control)
-            0
+            get_fun_control_key_value(fun_control=fun_control,
+                            key="key")
+            "value"
     """
-    # check if key "fun_evals" exists in fun_control:
-    if fun_control is None or "fun_evals" not in fun_control.keys():
+    # check if key exists in fun_control:
+    if fun_control is None or key not in fun_control.keys():
         return None
     else:
-        return fun_control["fun_evals"]
-
-
-def set_fun_control_fun_repeats(fun_control, fun_repeats) -> dict:
-    """
-    This function sets the number of function repeats in the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-        fun_repeats (int): number of function repeats
-
-    Returns:
-        fun_control (dict):
-            updated fun_control
-
-    Attributes:
-        fun_repeats (int): number of function repeats
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import set_fun_control_fun_repeats
-            fun_control = fun_control_init()
-            set_fun_control_fun_repeats(fun_control=fun_control,
-                          fun_repeats=5)
-            fun_control["fun_repeats"]
-
-    """
-    fun_control.update({"fun_repeats": fun_repeats})
-
-
-def get_fun_control_fun_repeats(fun_control=None) -> int:
-    """
-    This function gets the number of function repeats from the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-
-    Returns:
-        fun_repeats (int):
-            number of function repeats
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import get_fun_control_fun_repeats
-            fun_control = fun_control_init()
-            get_fun_control_fun_repeats(fun_control=fun_control)
-            0
-    """
-    # check if key "fun_repeats" exists in fun_control:
-    if fun_control is None or "fun_repeats" not in fun_control.keys():
-        return None
-    else:
-        return fun_control["fun_repeats"]
-
-
-def set_fun_control_seed(fun_control, seed) -> dict:
-    """
-    This function sets the seed in the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-        seed (int): seed
-
-    Returns:
-        fun_control (dict):
-            updated fun_control
-
-    Attributes:
-        seed (int): seed
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import set_fun_control_seed
-            fun_control = fun_control_init()
-            set_fun_control_seed(fun_control=fun_control,
-                          seed=5)
-            fun_control["seed"]
-
-    """
-    fun_control.update({"seed": seed})
-
-
-def get_fun_control_seed(fun_control=None) -> int:
-    """
-    This function gets the seed from the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-
-    Returns:
-        seed (int):
-            seed
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import get_fun_control_seed
-            fun_control = fun_control_init()
-            get_fun_control_seed(fun_control=fun_control)
-            0
-    """
-    # check if key "seed" exists in fun_control:
-    if fun_control is None or "seed" not in fun_control.keys():
-        return None
-    else:
-        return fun_control["seed"]
-
-
-def set_fun_control_sigma(fun_control, sigma) -> dict:
-    """
-    This function sets the sigma in the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-        sigma (float): sigma
-
-    Returns:
-        fun_control (dict):
-            updated fun_control
-
-    Attributes:
-        sigma (float): sigma
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import set_fun_control_sigma
-            fun_control = fun_control_init()
-            set_fun_control_sigma(fun_control=fun_control,
-                          sigma=5)
-            fun_control["sigma"]
-
-    """
-    fun_control.update({"sigma": sigma})
-
-
-def get_fun_control_sigma(fun_control=None) -> float:
-    """
-    This function gets the sigma from the fun_control dictionary.
-
-    Args:
-        fun_control (dict):
-            fun_control dictionary
-
-    Returns:
-        sigma (float):
-            sigma
-
-    Examples:
-        >>> from spotPython.utils.init import fun_control_init
-            from spotPython.hyperparameters.values import get_fun_control_sigma
-            fun_control = fun_control_init()
-            get_fun_control_sigma(fun_control=fun_control)
-            0
-    """
-    # check if key "sigma" exists in fun_control:
-    if fun_control is None or "sigma" not in fun_control.keys():
-        return None
-    else:
-        return fun_control["sigma"]
+        return fun_control[key]
